# coding: utf8

from setuptools import setup


setup(
    name="toyyaml",
    version="0.1",
    description="simple YAML format reader",
    author="yeyuexia",
    author_email="yyxworld@gmail.com",
    url="https://github.com/yeyuexia/toyyaml",
    packages=["toyyaml"]
)
